@@ -54,24 +54,30 @@ class DB(object):
             self.connection.commit()
             self.connection.close()
 
-    def execute(self, query, values=None):
+    def execute(self, query, values=None, many=False):
         cursor = None
         data = None
-
+        
         if self.connection:
             cursor = self.connection.cursor()
+            
+            # SELECT query
             if values == None:
                 cursor.execute(query)
+                data = cursor.fetchall()
+                    
+            # INSERT or REPLACE query
             else:
-                try:
+                if many:
+                    cursor.executemany(query, values)
+                else:
                     cursor.execute(query, values)
-                except Exception, e:
-                    print e.args[1]
-            data = cursor.fetchall()
+                    
             cursor.close()
-            return data
         else:
             raise Exception('You must connect first!')
+        
+        return data
 
     def __enter__(self):
         self.connect()
